@@ -105,6 +105,12 @@ class BaseSerializer(BaseField):
     def update(self, instance, validated_data):
         raise NotImplementedError('.update() must be implemented.')
 
+    def pre_serialize(self, data):
+        """
+        Hook for pre serialization.
+        """
+        return data
+
     def save(self, **kwargs):
         assert hasattr(self, '_errors'), (
             'You must call `.is_valid()` before calling `.save()`.'
@@ -193,7 +199,11 @@ class BaseSerializer(BaseField):
             )
 
         protobuf_list = []
-        self._protobuf = self.data
+        # run pre serialization hook
+        self._protobuf = getattr(
+            self.child, 'pre_serialize'
+        )(self.data) if hasattr(self, 'child') else getattr(self, 'pre_serialize')(self.data)
+
         if isinstance(self._protobuf, list):
             for item in self._protobuf:
                 protobuf_list.append(self.to_protobuf(item))
@@ -256,13 +266,14 @@ class ListSerializer(BaseSerializer):
         return [self.child.to_representation(item) for item in data]
 
     def to_protobuf(self, data):
-        return self.child.to_protobuf(
-            self.child.to_representation(data)
-        )
+        return self.child.to_protobuf(data)
 
     def create(self, validated_data):
         return [self.child.create(data) for data in validated_data]
 
+    def pre_serialize(self, data):
+        return data
+
     @staticmethod
     def validate(attrs):
         return attrs
